/*! edgebabel v0.2.2 by Sebastian Software <s.werner@sebastian-software.de> */
'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var appRootDir = require('app-root-dir');
var path = require('path');
var envPreset = _interopDefault(require('babel-preset-env'));
var reactPreset = _interopDefault(require('babel-preset-react'));
var flowPreset = _interopDefault(require('babel-preset-flow'));
var dynamicImportPlugin = _interopDefault(require('babel-plugin-syntax-dynamic-import'));
var moduleResolverPlugin = _interopDefault(require('babel-plugin-module-resolver'));
var fastAsyncPlugin = _interopDefault(require('babel-plugin-fast-async'));
var classPropertiesPlugin = _interopDefault(require('babel-plugin-transform-class-properties'));
var objectRestSpreadPlugin = _interopDefault(require('babel-plugin-transform-object-rest-spread'));
var lodashPlugin = _interopDefault(require('babel-plugin-lodash'));
var transformRuntimePlugin = _interopDefault(require('babel-plugin-transform-runtime'));
var reactIntlPlugin = _interopDefault(require('babel-plugin-react-intl'));
var removePropTypesPlugin = _interopDefault(require('babel-plugin-transform-react-remove-prop-types'));
var reactInlineElementsPlugin = _interopDefault(require('babel-plugin-transform-react-inline-elements'));
var reactConstantElements = _interopDefault(require('babel-plugin-transform-react-constant-elements'));

/* eslint-disable filenames/match-exported */
function buildPreset() {
  var opts = 1 < arguments.length && arguments[1] !== undefined ? arguments[1] : {},
      presets = [],
      plugins = [],
      options = Object.assign({}, {
    modules: "commonjs"
  }, opts),
      envValue = process.env.BABEL_ENV || process.env.NODE_ENV || "development";


  presets.push([envPreset, {
    // Setting this to false will not transform modules.
    modules: options.modules,

    // Prefer built-ins which also prefers global polyfills which is the right thing to do
    // for most scenarios like SPAs and NodeJS environments.
    useBuiltIns: true,

    loose: true,

    // We prefer the transpilation of the "fast-async" plugin over the
    // slower and more complex Babel internal implementation.
    exclude: ["transform-regenerator", "transform-async-to-generator"],

    // Differ between development and production for our scope.
    // NodeJS is generally fine in development to match the runtime version which is currently installed.
    targets: {
      browsers: ["last 2 versions"],
      node: "current"
    }
  }]);

  presets.push(reactPreset);
  presets.push(flowPreset);

  // Support for new @import() syntax
  plugins.push(dynamicImportPlugin);

  // Optimization for lodash imports.
  // Auto cherry-picking es2015 imports from path imports.
  plugins.push(lodashPlugin);

  // Supports loading files in source folder without relative folders
  plugins.push([moduleResolverPlugin, {
    root: [path.resolve(appRootDir.get(), "src")]
  }]);

  // Alternative to Babel Regenerator
  // Implements the ES7 keywords async and await using syntax transformation at compile-time, rather than generators.
  plugins.push([fastAsyncPlugin, {
    useRuntimeModule: true
  }]);

  // Support for ES7 Class Properties (currently stage-2)
  plugins.push(classPropertiesPlugin);

  // Support for Object Rest Spread `...` operator in objects.
  plugins.push([objectRestSpreadPlugin, { useBuiltIns: true }]);

  // Use helpers, but not polyfills, in a way that omits duplication.
  // For polyfills better use polyfill.io or another more sophisticated solution.
  plugins.push([transformRuntimePlugin, {
    regenerator: false,
    polyfill: false,
    useBuiltIns: true,
    useESModules: true
  }]);

  if ("production" === envValue) {
    // Cleanup descriptions for translations from compilation output
    plugins.push(reactIntlPlugin);

    // Remove prop types from our code
    plugins.push([removePropTypesPlugin, { removeImport: true }]);

    // Replaces the React.createElement function with one that is
    // more optimized for production.
    // NOTE: Symbol needs to be polyfilled.
    plugins.push(reactInlineElementsPlugin);

    // Hoists element creation to the top level for subtrees that
    // are fully static, which reduces call to React.createElement
    // and the resulting allocations. More importantly, it tells
    // React that the subtree hasn’t changed so React can completely
    // skip it when reconciling.
    plugins.push(reactConstantElements);
  }

  // Assemble final config
  return {
    presets: presets,
    plugins: plugins
  };
}

module.exports = buildPreset;
//# sourceMappingURL=node.commonjs.js.map
